@@ -1,9 +1,12 @@
 from __future__ import annotations
-from typing import List
+from typing import Dict, List
 
 class Metadata:
-    def __init__(self, output_channel:str=None):
+    def __init__(self, predecessors:List[str], fragment_id:str=None, output_channel:str=None, custom:Dict[str, str]=None):
         self.output_channel = output_channel
+        self.custom = custom
+        self.fragment_id = fragment_id
+        self.predecessors = predecessors
     
     def __str__(self):
         return str(self.__dict__)
@@ -15,7 +18,7 @@ class Metadata:
     def from_json(cls, d:dict) -> cls:
         if not isinstance(d, dict):
             raise TypeError("Argument 'd' is not of type 'dict'")
-        result = cls()
+        result = cls([])
         for key in d.keys():
             result.__setattr__(key, d[key])
 
